==> helidon-docs-1.0.1.jar: pages/extensions/01_overview.js <==
<doc-view>

<h2 id="_cdi_extensions">CDI extensions</h2>
<div class="section">
<p>Helidon provides <a id="" title="" target="_blank" href="https://docs.jboss.org/cdi/spec/2.0/cdi-spec.html#spi">CDI portable extensions</a> that you
 can use to inject the following objects into your Helidon MicroProfile
 applications:</p>

<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/extensions/02_cdi_datasource-hikaricp"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">HikariCP data sources</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create and inject a HikariCP data source in your application code.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/extensions/03_cdi_jedis"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Jedis clients</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create and inject a Jedis pool in your application code.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/extensions/04_cdi_oci-objectstorage"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">OCI Object Storage clients</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create and inject an Oracle Cloud Infrastructure Object Storage client in your
application code.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>
</doc-view>

==> helidon-docs-1.2.0.jar: pages/extensions/01_overview.js <==
<doc-view>

<h2 id="_cdi_extensions">CDI extensions</h2>
<div class="section">
<p>Helidon provides <a id="" title="" target="_blank" href="https://docs.jboss.org/cdi/spec/2.0/cdi-spec.html#spi">CDI portable extensions</a> that you
 can use to inject the following objects into your Helidon MicroProfile
 applications:</p>

<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/extensions/02_cdi_datasource-hikaricp"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">HikariCP data sources</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create and inject a HikariCP data source in your application code.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/extensions/03_cdi_jedis"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Jedis clients</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create and inject a Jedis pool in your application code.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/extensions/04_cdi_oci-objectstorage"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">OCI Object Storage clients</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create and inject an Oracle Cloud Infrastructure Object Storage client in your
application code.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/extensions/05_cdi_jta"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Java Transaction API objects</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Use the Java Transaction API in your application code.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>
</doc-view>
